Picocolors class

The subset of picocolors' color functions used by the dotweave CLI.

Properties

hashCode int
The hash code for this object.
no setterinherited
isColorSupported bool
Whether the style functions emit ANSI color sequences.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bold(String input) String
Applies the bold style to input.
cyan(String input) String
Applies the cyan foreground color to input.
dim(String input) String
Applies the dim style to input.
green(String input) String
Applies the green foreground color to input.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
red(String input) String
Applies the red foreground color to input.
toString() String
A string representation of this object.
inherited
yellow(String input) String
Applies the yellow foreground color to input.

Operators

operator ==(Object other) bool
The equality operator.
inherited