Symbols class
Mirror of the TS SYMBOLS const object.
Constructors
- Symbols()
-
The symbols used for terminal output.
const
Properties
- add → String
-
Symbol for an added item.
final
- arrow → String
-
Symbol for a directional relationship.
final
- bullet → String
-
Symbol for a list bullet.
final
- delete → String
-
Symbol for a deleted item.
final
- error → String
-
Symbol for an error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → String
-
Symbol for informational output.
final
- modify → String
-
Symbol for a modified item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- section → String
-
Symbol for a section heading.
final
-
spinner
→ List<
String> -
Animation frames for a terminal spinner.
final
- success → String
-
Symbol for a successful result.
final
- warn → String
-
Symbol for a warning.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited