ApplicationFlag<C extends CommandContext> class
final
An application-level flag installed by an integration.
Constructors
-
ApplicationFlag({required String brief, required FutureOr<
void> run(ApplicationFlagArguments<C> arguments), List<String> aliases = const [], bool global = false, bool complete = true, bool defaultForRouteMap = false}) -
Creates an application flag.
const
Properties
-
aliases
→ List<
String> -
Single-character aliases.
final
- brief → String
-
Description shown in help and completion.
final
- complete → bool
-
Whether completion proposes the flag.
final
- defaultForRouteMap → bool
-
Whether this flag runs for an otherwise-unhandled route map.
final
- global → bool
-
Whether the flag is active below the root target.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether normal help and completion hide the flag.
final
-
run
→ FutureOr<
void> Function(ApplicationFlagArguments<C> arguments) -
Executes the flag.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited