ArgumentParseError class final
Failed to parse "…" for …: ….
- Inheritance
-
- Object
- ArgumentScannerError
- ArgumentParseError
Constructors
- ArgumentParseError(String externalFlagNameOrPlaceholder, String input, Object exception)
- Creates an ArgumentParseError.
Properties
- exception → Object
-
The exception value.
final
- externalFlagNameOrPlaceholder → String
-
The external flag name or placeholder value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → String
-
The input value.
final
- message → String
-
The human-readable message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited