EnumValidationError class final
Expected "…" to be one of (…).
- Inheritance
-
- Object
- ArgumentScannerError
- EnumValidationError
Constructors
-
EnumValidationError(String externalFlagName, String input, List<
String> values, List<String> corrections) - Creates an EnumValidationError.
Properties
- externalFlagName → String
-
The flag name as entered by the user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → String
-
The input value.
final
- message → String
-
The human-readable message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
String> -
The accepted values.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited