RunContext<C extends CommandContext> class
final
Runtime context source used by run, runApplication, and completion.
Constructors
- RunContext.direct(C context, {String? locale})
-
Uses one prebuilt context for every command.
factory
-
RunContext.forCommands({required ApplicationContext application, required CommandContextBuilder<
C> load}) -
Creates context independently for each selected command.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited