ColorActionTheme class
Mirror of the nested color.action object.
Constructors
- ColorActionTheme({Picocolors? pc})
- Creates a ColorActionTheme.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
String s) → String -
Styles
sas an added item. -
delete(
String s) → String -
Styles
sas a deleted item. -
modify(
String s) → String -
Styles
sas a modified item. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited