ColorTheme class
Mirror of the TS color const object. The optional Picocolors override
is the DI seam replacing the vitest module mock of picocolors.
Constructors
- ColorTheme({Picocolors? pc})
- Creates a ColorTheme.
Properties
- action → ColorActionTheme
-
Styles used for added, modified, and deleted items.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bold(
String s) → String -
Emphasizes
s. -
dim(
String s) → String -
Styles
sas secondary output. -
error(
String s) → String -
Styles
sas error output. -
header(
String s) → String -
Styles
sas a heading. -
highlight(
String s) → String -
Highlights
s. -
info(
String s) → String -
Styles
sas informational output. -
label(
String s) → String -
Styles
sas a label. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
String s) → String -
Styles
sas a command path. -
success(
String s) → String -
Styles
sas successful output. -
toString(
) → String -
A string representation of this object.
inherited
-
warn(
String s) → String -
Styles
sas warning output.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited