Spinner class abstract
Mirror of the TS Spinner interface.
Constructors
- Spinner()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fail(
String text) → void -
Stops the spinner and reports
textas a failure. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stop(
) → void - Stops the spinner without reporting a result.
-
succeed(
String text) → void -
Stops the spinner and reports
textas a success. -
toString(
) → String -
A string representation of this object.
inherited
-
warn(
String text) → void -
Stops the spinner and reports
textas a warning.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited